@@ -40,7 +40,10 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 #include <math.h>
+#include <stdio.h>
+
 
 #include <X11/Xlib.h>
 
@@ -51,6 +54,7 @@
 #include <unistd.h>
 #include <grp.h>
 #include <pwd.h>
+#include <sys/time.h>
 
 #include "config.h"
 
@@ -111,10 +115,8 @@ void infos_cd();
 
 /* External functions */
 
-extern time();
-extern open();
-extern cd_control(int);
-extern cd_control_version();
+extern void cd_control(int);
+extern char* cd_control_version();
 
 /* These #defines control the main loop timeouts */
 #define RDTIME 50000L
@@ -218,6 +220,7 @@ unsigned int no_mask = TRUE;
 */
 
 unsigned int panel = 0;
+Atom _XA_WM_DELETE_WINDOW 	= None;
 
 /*
 #define BMAX 16
@@ -640,7 +643,7 @@ void cdplayer_mouse_events(XEvent Event)
 		    theme_select --;
 		    if (theme_select == 1) theme_select = theme_select_nbr;
 		    sprintf(txt, "%s/.dir", THDIR);
-		    if (in = fopen(txt, "r")) {
+		    if( (in = fopen(txt, "r"))!= NULL ) {
 			i = 0;
 			while (fgets(txt, 255,in)) {
 			    i++;
@@ -662,7 +665,7 @@ void cdplayer_mouse_events(XEvent Event)
 		    theme_select ++;
 		    if (theme_select > theme_select_nbr) theme_select = 1;
 		    sprintf(txt, "%s/.dir", THDIR);
-		    if (in = fopen(txt, "r")) {
+		    if ((in = fopen(txt, "r"))!=NULL) {
 			i = 0;
 			while (fgets(txt, 255,in)) {
 			    i++;
@@ -695,13 +698,13 @@ void cdplayer_mouse_events(XEvent Event)
 
 		sprintf(txt, "%s/.dir", THDIR);
 		theme_select_nbr = 0;
-		if (in = fopen(txt, "r")) {
+		if( (in = fopen(txt, "r"))!= NULL ) {
 		    while (fgets(txt, 255,in)) theme_select_nbr++;
 		    fclose(in);
 		}
 
 		sprintf(txt, "%s/.dir", THDIR);
-		if (in = fopen(txt, "r")) {
+		if ((in = fopen(txt, "r")) != NULL ) {
 		    i = 0;
 		    while (fgets(txt, 255, in)) {
 			i++;
@@ -925,7 +928,6 @@ void GetXPM(char *foreground, char *background)
     char txt[256];
     XWindowAttributes Attributes;
     int Ret;
-    FILE *in;
 
     sprintf(txt, "%s/%s", THDIR, theme);
     if (access(txt, X_OK | R_OK) != 0) {
@@ -1092,6 +1094,8 @@ void CreateWindow(int argc, char **argv)
     Root = RootWindow(Disp, screen);
     d_depth = DefaultDepth(Disp, screen);
     x_fd = XConnectionNumber(Disp);
+    _XA_WM_DELETE_WINDOW = XInternAtom (Disp, "WM_DELETE_WINDOW", False);
+    
     ScreenHeight = DisplayHeight(Disp,screen);
     ScreenWidth = DisplayWidth(Disp,screen);
 
@@ -1149,6 +1153,7 @@ void CreateWindow(int argc, char **argv)
     WmHints.icon_x = SizeHints.x;
     WmHints.icon_y = SizeHints.y;
     XSetWMHints(Disp, Win, &WmHints);
+    XSetWMProtocols (Disp, Win, &_XA_WM_DELETE_WINDOW, 1);
     XSetCommand(Disp, Win, argv, argc);
     
     XMapWindow(Disp, Win);
@@ -1284,7 +1289,7 @@ void show_db_f() {
 		Text_Draw(txt2, 0, 1, TRUE);
 	    }
 	} else {
-	    sprintf(txt, "");
+	    *txt = '\0';
 	}
     }
 }
@@ -1478,9 +1483,9 @@ void MaskSet() {
 
 void RedrawWindow(XpmIcon *Icon) {
     int disp_time;
-    static time_t last_flash_time;
-    static flash=0;
-    long int dodo = 300000;
+    static time_t last_flash_time = 0;
+    static int flash=0;
+    long dodo = 300000;
     char cdtime[6];
     char txt[40];
     int i;
@@ -1691,8 +1696,8 @@ void RedrawWindow(XpmIcon *Icon) {
 	
 	i = 0;
 	sprintf(txt, "%s/.dir", THDIR);
-	if (in = fopen(txt, "r")) {
-	    while (fgets(txt, 255,in)) {
+	if( (in = fopen(txt, "r"))!= NULL ) {
+	    while (fgets(txt, 255,in)!=NULL) {
 		i++;
 		txt[strlen(txt) - 1] = 0;
 		if (i == theme_select) {
@@ -1886,11 +1891,14 @@ void MainLoop()
 		    break;
 		    
 		    /* ------------------------ Destroy Window ------------------- */
-		    
+	        case ClientMessage:
+    		  if ((Event.xclient.format != 32) ||
+		      (Event.xclient.data.l[0] != _XA_WM_DELETE_WINDOW))
+		      break;
 		case DestroyNotify:
 		    XFreeGC(Disp, WinGC);
-		    XDestroyWindow(Disp, Win);
 		    XDestroyWindow(Disp, Iconwin);
+		    XDestroyWindow(Disp, Win);
 		    XCloseDisplay(Disp);
 		    exit(0);
 		    break;
