@@ -179,9 +179,10 @@ void track_select(WMWidget *self, void *data) {
     if (cur_cdmode == WM_CDM_STOPPED) cd_control(PLAY);
 }
 
-void theme_select(WMWidget *self, void *data) {
+void theme_pick(WMWidget *self, void *data) {
     strcpy(theme, WMGetPopUpButtonItem(self, WMGetPopUpButtonSelectedItem(self)   )   );
-    GetXPM(led_color, led_bgcolor);
+    (void)GetXPM(led_color, led_bgcolor);
+    (void)MaskSet();
 }
 
 void mode1_cb(WMWidget *self, void *data) {
@@ -698,8 +699,7 @@ void create_big_window(WMScreen *scr) {
     /*WMSetPopUpButtonPullsDown(pop2, True);*/
     WMSetPopUpButtonText(pop2, theme);
     WMAddPopUpButtonItem(pop2, "1");
-    WMSetPopUpButtonAction(pop2, theme_select, NULL); 
-
+    WMSetPopUpButtonAction(pop2, theme_pick, NULL); 
 
     /* the volume */
 
@@ -749,10 +749,6 @@ void create_big_window(WMScreen *scr) {
     WMResizeWidget(b_fadestep, 25, 20);
     WMMoveWidget(b_fadestep, 275, 260);
 
-
-
-
-
     /* the counter modes */
 
     fr5 = WMCreateFrame(win);
@@ -818,7 +814,6 @@ void create_big_window(WMScreen *scr) {
     WMMapSubwidgets(win);
     WMMapWidget(win);
     */
-
 }
 
 void update_track() {
@@ -941,6 +936,7 @@ void big_window(WMScreen *scr) {
 	    }
 	    fclose(in);
 	}
+	WMSetPopUpButtonText(pop2, theme);
 
 	if (cd->trk[cur_track - 1].songname != NULL) {
 	    sprintf(txt, "%s", cd->trk[cur_track - 1].songname);
@@ -989,6 +985,8 @@ void big_window(WMScreen *scr) {
 	    WMSetButtonSelected(b_upper, FALSE);
 	}
 
+	/* yyy */
+
 	switch(time_mode) {
 	case 0:
 	    WMSetButtonSelected((b_mode1), TRUE);
